Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3)

Unified Diff: chrome/android/javatests/src/org/chromium/chrome/browser/payments/PaymentRequestIncompletePayerInfoDetailsTest.java

Issue 2413833002: PaymentRequest: Rename ContactInfo to PayerInfo.
Patch Set: test Created 4 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/android/javatests/src/org/chromium/chrome/browser/payments/PaymentRequestIncompletePayerInfoDetailsTest.java
diff --git a/chrome/android/javatests/src/org/chromium/chrome/browser/payments/PaymentRequestIncompleteContactDetailsTest.java b/chrome/android/javatests/src/org/chromium/chrome/browser/payments/PaymentRequestIncompletePayerInfoDetailsTest.java
similarity index 65%
rename from chrome/android/javatests/src/org/chromium/chrome/browser/payments/PaymentRequestIncompleteContactDetailsTest.java
rename to chrome/android/javatests/src/org/chromium/chrome/browser/payments/PaymentRequestIncompletePayerInfoDetailsTest.java
index 5ac9f6eca77dc80cee69b9937a738dee79856526..6b0ff5e3e99c58df53690c6dd6504e71003dc51e 100644
--- a/chrome/android/javatests/src/org/chromium/chrome/browser/payments/PaymentRequestIncompleteContactDetailsTest.java
+++ b/chrome/android/javatests/src/org/chromium/chrome/browser/payments/PaymentRequestIncompletePayerInfoDetailsTest.java
@@ -17,13 +17,13 @@ import java.util.concurrent.ExecutionException;
import java.util.concurrent.TimeoutException;
/**
* A payment integration test for a merchant that requests contact details from a user that has
* incomplete contact details stored on disk.
*/
-public class PaymentRequestIncompleteContactDetailsTest extends PaymentRequestTestBase {
- public PaymentRequestIncompleteContactDetailsTest() {
- // This merchant requests both a phone number and an email address.
- super("payment_request_contact_details_test.html");
+public class PaymentRequestIncompletePayerInfoDetailsTest extends PaymentRequestTestBase {
+ public PaymentRequestIncompletePayerInfoDetailsTest() {
+ // This merchant requests payer information.
+ super("payment_request_payer_info_details_test.html");
}
@Override
@@ -39,35 +39,35 @@ public class PaymentRequestIncompleteContactDetailsTest extends PaymentRequestTe
billingAddressId, "" /* serverId */));
}
/** Attempt to update the contact information with invalid data and cancel the transaction. */
@MediumTest
@Feature({"Payments"})
- public void testEditIncompleteContactAndCancel()
+ public void testEditIncompletePayerInfoAndCancel()
throws InterruptedException, ExecutionException, TimeoutException {
triggerUIAndWait(mReadyForInput);
- clickInContactInfoAndWait(R.id.payments_section, mReadyForInput);
- clickInContactInfoAndWait(R.id.payments_first_radio_button, mReadyToEdit);
- setTextInEditorAndWait(new String[] {"---", "jane.jones"}, mEditorTextUpdate);
+ clickInPayerInfoAndWait(R.id.payments_section, mReadyForInput);
+ clickInPayerInfoAndWait(R.id.payments_first_radio_button, mReadyToEdit);
+ setTextInEditorAndWait(new String[] {"", "---", "jane.jones"}, mEditorTextUpdate);
clickInEditorAndWait(R.id.payments_edit_done_button, mEditorValidationError);
clickInEditorAndWait(R.id.payments_edit_cancel_button, mReadyForInput);
clickAndWait(R.id.close_button, mDismissed);
expectResultContains(new String[] {"Request cancelled"});
}
/** Update the contact information with valid data and provide that to the merchant. */
@MediumTest
@Feature({"Payments"})
- public void testEditIncompleteContactAndPay()
+ public void testEditIncompletePayerInfoAndPay()
throws InterruptedException, ExecutionException, TimeoutException {
triggerUIAndWait(mReadyForInput);
- clickInContactInfoAndWait(R.id.payments_section, mReadyForInput);
- clickInContactInfoAndWait(R.id.payments_first_radio_button, mReadyToEdit);
- setTextInEditorAndWait(new String[] {"555-555-5555", "jon.doe@google.com"},
+ clickInPayerInfoAndWait(R.id.payments_section, mReadyForInput);
+ clickInPayerInfoAndWait(R.id.payments_first_radio_button, mReadyToEdit);
+ setTextInEditorAndWait(new String[] {"Jon Doe", "555-555-5555", "jon.doe@google.com"},
mEditorTextUpdate);
clickInEditorAndWait(R.id.payments_edit_done_button, mReadyToPay);
clickAndWait(R.id.button_primary, mReadyForUnmaskInput);
setTextInCardUnmaskDialogAndWait(R.id.card_unmask_input, "123", mReadyToUnmask);
clickCardUnmaskButtonAndWait(DialogInterface.BUTTON_POSITIVE, mDismissed);
- expectResultContains(new String[] {"555-555-5555", "jon.doe@google.com"});
+ expectResultContains(new String[] {"Jon Doe", "555-555-5555", "jon.doe@google.com"});
}
}
@@ -17,13 +17,13 @@ import java.util.concurrent.ExecutionException;
import java.util.concurrent.TimeoutException;
/**
- * A payment integration test for a merchant that requests contact details from a user that has
- * incomplete contact details stored on disk.
+ * A payment integration test for a merchant that requests payer information details from a user
+ * that has incomplete payer information details stored on disk.
*/
@@ -39,35 +39,35 @@ public class PaymentRequestIncompleteContactDetailsTest extends PaymentRequestTe
billingAddressId, "" /* serverId */));
}
- /** Attempt to update the contact information with invalid data and cancel the transaction. */
+ /** Attempt to update the payer information with invalid data and cancel the transaction. */
@@ -39,35 +39,35 @@ public class PaymentRequestIncompleteContactDetailsTest extends PaymentRequestTe
expectResultContains(new String[] {"Request cancelled"});
}
- /** Update the contact information with valid data and provide that to the merchant. */
+ /** Update the payer information with valid data and provide that to the merchant. */

Powered by Google App Engine
This is Rietveld 408576698